@@ -540,3 +540,13 @@ class TestClangDelta(unittest.TestCase):
         run = subprocess.run(cmd, shell=True, encoding='utf8', stderr=subprocess.PIPE, stdout=subprocess.PIPE)
         assert 'Available transformation instances: 1' in run.stderr
         assert 'Warning: number of transformation instances exceeded' in run.stderr
+
+    def test_simple_inliner_alias(self):
+        self.check_clang_delta('simple-inliner/alias-crash.c', '--transformation=simple-inliner --counter=1')
+
+    def test_class_to_struct(self):
+        self.check_clang_delta('class-to-struct/class-to-struct1.C', '--transformation=class-to-struct --counter=1')
+
+    def test_class_to_struct_forward(self):
+        self.check_query_instances('class-to-struct/class-to-struct-forward.C', '--query-instances=class-to-struct',
+                                   'Available transformation instances: 0')
