@@ -19,10 +19,10 @@ if importlib.util.find_spec('cvise') is None:
     sys.path.append('@CMAKE_INSTALL_FULL_DATADIR@')
     sys.path.append(destdir + '@CMAKE_INSTALL_FULL_DATADIR@')
 
+import chardet  # noqa: E402
 from cvise.cvise import CVise  # noqa: E402
 from cvise.passes.abstract import AbstractPass  # noqa: E402
-from cvise.utils import statistics  # noqa: E402
-from cvise.utils import testing  # noqa: E402
+from cvise.utils import misc, statistics, testing  # noqa: E402
 from cvise.utils.error import CViseError  # noqa: E402
 from cvise.utils.error import MissingPassGroupsError  # noqa: E402
 import psutil  # noqa: E402
@@ -62,6 +62,7 @@ def find_external_programs():
         'clex': 'clex',
         'topformflat': 'delta',
         'unifdef': None,
+        'gcov-dump': None
     }
 
     for prog, local_folder in programs.items():
@@ -126,6 +127,29 @@ def get_available_pass_groups():
     return group_names
 
 
+def get_available_cores():
+    try:
+        # try to detect only physical cores, ignore HyperThreading
+        # in order to speed up parallel execution
+        core_count = psutil.cpu_count(logical=False)
+        if not core_count:
+            core_count = psutil.cpu_count(logical=True)
+        # respect affinity
+        try:
+            affinity = len(psutil.Process().cpu_affinity())
+            assert affinity >= 1
+        except AttributeError:
+            return core_count
+
+        if core_count:
+            core_count = min(core_count, affinity)
+        else:
+            core_count = affinity
+        return core_count
+    except NotImplementedError:
+        return 1
+
+
 EPILOG_TEXT = """
 available shortcuts:
   S - skip execution of the current pass
@@ -136,43 +160,28 @@ For bug reporting instructions, please use:
 """ % CVise.Info.PACKAGE_URL
 
 if __name__ == '__main__':
-    try:
-        # try to detect only physical cores, ignore HyperThreading
-        # in order to speed up parallel execution
-        core_count = psutil.cpu_count(logical=False)
-        if not core_count:
-            core_count = psutil.cpu_count(logical=True)
-        # respect affinity
-        affinity = len(psutil.Process().cpu_affinity())
-        assert affinity >= 1
-        if core_count:
-            core_count = min(core_count, affinity)
-        else:
-            core_count = affinity
-    except NotImplementedError:
-        core_count = 1
-
     parser = argparse.ArgumentParser(description='C-Vise', formatter_class=argparse.RawDescriptionHelpFormatter, epilog=EPILOG_TEXT)
-    parser.add_argument('--n', '-n', type=int, default=core_count, help='Number of cores to use; C-Vise tries to automatically pick a good setting but its choice may be too low or high for your situation')
-    parser.add_argument('--tidy', action='store_true', default=False, help='Do not make a backup copy of each file to reduce as file.orig')
-    parser.add_argument('--shaddap', action='store_true', default=False, help='Suppress output about non-fatal internal errors')
-    parser.add_argument('--die-on-pass-bug', action='store_true', default=False, help='Terminate C-Vise if a pass encounters an otherwise non-fatal problem')
-    parser.add_argument('--sllooww', action='store_true', default=False, help='Try harder to reduce, but perhaps take a long time to do so')
+    parser.add_argument('--n', '-n', type=int, default=get_available_cores(), help='Number of cores to use; C-Vise tries to automatically pick a good setting but its choice may be too low or high for your situation')
+    parser.add_argument('--tidy', action='store_true', help='Do not make a backup copy of each file to reduce as file.orig')
+    parser.add_argument('--shaddap', action='store_true', help='Suppress output about non-fatal internal errors')
+    parser.add_argument('--die-on-pass-bug', action='store_true', help='Terminate C-Vise if a pass encounters an otherwise non-fatal problem')
+    parser.add_argument('--sllooww', action='store_true', help='Try harder to reduce, but perhaps take a long time to do so')
     parser.add_argument('--also-interesting', metavar='EXIT_CODE', type=int, help='A process exit code (somewhere in the range 64-113 would be usual) that, when returned by the interestingness test, will cause C-Vise to save a copy of the variant')
-    parser.add_argument('--debug', action='store_true', default=False, help='Print debug information (alias for --log-level=DEBUG)')
+    parser.add_argument('--debug', action='store_true', help='Print debug information (alias for --log-level=DEBUG)')
     parser.add_argument('--log-level', type=str, choices=['INFO', 'DEBUG', 'WARNING', 'ERROR'], default='INFO', help='Define the verbosity of the logged events')
     parser.add_argument('--log-file', type=str, help='Log events into LOG_FILE instead of stderr. New events are appended to the end of the file')
-    parser.add_argument('--no-give-up', action='store_true', default=False, help="Don't give up on a pass that hasn't made progress for {} iterations".format(testing.TestManager.GIVEUP_CONSTANT))
-    parser.add_argument('--print-diff', action='store_true', default=False, help='Show changes made by transformations, for debugging')
-    parser.add_argument('--save-temps', action='store_true', default=False, help="Don't delete /tmp/cvise-xxxxxx directories on termination")
-    parser.add_argument('--skip-initial-passes', action='store_true', default=False, help='Skip initial passes (useful if input is already partially reduced)')
+    parser.add_argument('--no-give-up', action='store_true', help="Don't give up on a pass that hasn't made progress for {} iterations".format(testing.TestManager.GIVEUP_CONSTANT))
+    parser.add_argument('--print-diff', action='store_true', help='Show changes made by transformations, for debugging')
+    parser.add_argument('--save-temps', action='store_true', help="Don't delete /tmp/cvise-xxxxxx directories on termination")
+    parser.add_argument('--skip-initial-passes', action='store_true', help='Skip initial passes (useful if input is already partially reduced)')
+    parser.add_argument('--skip-interestingness-test-check', '-s', action='store_true', help='Skip initial interestingness test check')
     parser.add_argument('--remove-pass', help='Remove all instances of the specified passes from the schedule (comma-separated)')
     parser.add_argument('--start-with-pass', help='Start with the specified pass')
-    parser.add_argument('--no-timing', action='store_true', default=False, help='Do not print timestamps about reduction progress')
-    parser.add_argument('--timestamp', action='store_true', default=False, help='Print timestamps instead of relative time from a reduction start')
+    parser.add_argument('--no-timing', action='store_true', help='Do not print timestamps about reduction progress')
+    parser.add_argument('--timestamp', action='store_true', help='Print timestamps instead of relative time from a reduction start')
     parser.add_argument('--timeout', type=int, nargs='?', default=300, help='Interestingness test timeout in seconds')
-    parser.add_argument('--no-cache', action='store_true', default=False, help="Don't cache behavior of passes")
-    parser.add_argument('--skip-key-off', action='store_true', default=False, help="Disable skipping the rest of the current pass when 's' is pressed")
+    parser.add_argument('--no-cache', action='store_true', help="Don't cache behavior of passes")
+    parser.add_argument('--skip-key-off', action='store_true', help="Disable skipping the rest of the current pass when 's' is pressed")
     parser.add_argument('--max-improvement', metavar='BYTES', type=int, help='Largest improvement in file size from a single transformation that C-Vise should accept (useful only to slow C-Vise down)')
     passes_group = parser.add_mutually_exclusive_group()
     passes_group.add_argument('--pass-group', type=str, choices=get_available_pass_groups(), help='Set of passes used during the reduction')
@@ -184,6 +193,7 @@ if __name__ == '__main__':
     parser.add_argument('--list-passes', action='store_true', help='Print all available passes and exit')
     parser.add_argument('--version', action='version', version=CVise.Info.PACKAGE_STRING + (' (%s)' % CVise.Info.GIT_VERSION if CVise.Info.GIT_VERSION != 'unknown' else ''))
     parser.add_argument('--commands', '-c', help='Use bash commands instead of an interestingness test case')
+    parser.add_argument('--to-utf8', action='store_true', help='Convert any non-UTF-8 encoded input file to UTF-8')
     parser.add_argument('interestingness_test', metavar='INTERESTINGNESS_TEST', nargs='?', help='Executable to check interestingness of test cases')
     parser.add_argument('test_cases', metavar='TEST_CASE', nargs='+', help='Test cases')
 
@@ -260,6 +270,16 @@ if __name__ == '__main__':
         args.test_cases.insert(0, args.interestingness_test)
         args.interestingness_test = None
 
+    if args.to_utf8:
+        for test_case in args.test_cases:
+            with open(test_case, 'rb') as fd:
+                encoding = chardet.detect(fd.read())['encoding']
+                if encoding not in ('ascii', 'utf-8'):
+                    logging.info(f'Converting {test_case} file ({encoding} encoding) to UTF-8')
+                    data = open(test_case, 'r', encoding=encoding).read()
+                    with open(test_case, 'w') as w:
+                        w.write(data)
+
     script = None
     if args.commands:
         with tempfile.NamedTemporaryFile(mode='w', delete=False, suffix='.sh') as script:
@@ -274,7 +294,7 @@ if __name__ == '__main__':
                                        args.die_on_pass_bug, args.print_diff, args.max_improvement, args.no_give_up, args.also_interesting,
                                        args.start_with_pass)
 
-    reducer = CVise(test_manager)
+    reducer = CVise(test_manager, args.skip_interestingness_test_check)
 
     reducer.tidy = args.tidy
 
@@ -303,9 +323,10 @@ if __name__ == '__main__':
 
         print('Reduced test-cases:\n')
         for test_case in sorted(test_manager.test_cases):
-            print(f'--- {test_case} ---')
-            with open(test_case) as test_case_file:
-                print(test_case_file.read())
+            if misc.is_readable_file(test_case):
+                print(f'--- {test_case} ---')
+                with open(test_case) as test_case_file:
+                    print(test_case_file.read())
         if script:
             os.unlink(script.name)
 
