@@ -9,6 +9,7 @@ from cvise.passes.clang import ClangPass
 from cvise.passes.clangbinarysearch import ClangBinarySearchPass
 from cvise.passes.clex import ClexPass
 from cvise.passes.comments import CommentsPass
+from cvise.passes.gcdabinary import GCDABinaryPass
 from cvise.passes.ifs import IfPass
 from cvise.passes.includeincludes import IncludeIncludesPass
 from cvise.passes.includes import IncludesPass
@@ -42,6 +43,7 @@ class CVise:
         'clangbinarysearch': ClangBinarySearchPass,
         'clex': ClexPass,
         'comments': CommentsPass,
+        'gcda-binary': GCDABinaryPass,
         'ifs': IfPass,
         'includeincludes': IncludeIncludesPass,
         'includes': IncludesPass,
@@ -55,8 +57,9 @@ class CVise:
         'unifdef': UnIfDefPass,
     }
 
-    def __init__(self, test_manager):
+    def __init__(self, test_manager, skip_interestingness_test_check):
         self.test_manager = test_manager
+        self.skip_interestingness_test_check = skip_interestingness_test_check
         self.tidy = False
 
     @classmethod
@@ -117,7 +120,7 @@ class CVise:
                 elif not renaming and 'renaming' in pass_dict and pass_dict['renaming']:
                     continue
 
-                pass_instance.clang_delta_std = clang_delta_std
+                pass_instance.user_clang_delta_std = clang_delta_std
                 pass_instance.clang_delta_preserve_routine = clang_delta_preserve_routine
                 pass_group[category].append(pass_instance)
 
@@ -125,7 +128,8 @@ class CVise:
 
     def reduce(self, pass_group, skip_initial):
         self._check_prerequisites(pass_group)
-        self.test_manager.check_sanity(True)
+        if not self.skip_interestingness_test_check:
+            self.test_manager.check_sanity(True)
 
         logging.info('===< {} >==='.format(os.getpid()))
         logging.info('running {} interestingness test{} in parallel'.format(self.test_manager.parallel_tests,
