@@ -23,8 +23,8 @@ class ClangPass(AbstractPass):
         tmp = os.path.dirname(test_case)
         with tempfile.NamedTemporaryFile(mode='w', delete=False, dir=tmp) as tmp_file:
             args = [self.external_programs['clang_delta'], '--transformation={}'.format(self.arg), '--counter={}'.format(state)]
-            if self.clang_delta_std:
-                args.append('--std={}'.format(self.clang_delta_std))
+            if self.user_clang_delta_std:
+                args.append('--std={}'.format(self.user_clang_delta_std))
             cmd = args + [test_case]
 
             logging.debug(' '.join(cmd))
