@@ -8,6 +8,8 @@ import os
 import os.path
 import platform
 import shutil
+import subprocess
+import sys
 import tempfile
 import traceback
 
@@ -19,6 +21,7 @@ from cvise.utils.error import InvalidInterestingnessTestError
 from cvise.utils.error import InvalidTestCaseError
 from cvise.utils.error import PassBugError
 from cvise.utils.error import ZeroSizeError
+from cvise.utils.misc import is_readable_file
 from cvise.utils.readkey import KeyLogger
 import pebble
 import psutil
@@ -160,12 +163,15 @@ class TestManager:
         self.orig_total_file_size = self.total_file_size
         self.cache = {}
         self.root = None
-
         if not self.is_valid_test(self.test_script):
             raise InvalidInterestingnessTestError(self.test_script)
 
+        self.use_colordiff = (sys.stdout.isatty() and
+                              subprocess.run('colordiff --version', shell=True, stdout=subprocess.DEVNULL).returncode == 0)
+
     def create_root(self):
-        self.root = tempfile.mkdtemp(prefix=self.TEMP_PREFIX)
+        pass_name = str(self.current_pass).replace('::', '-')
+        self.root = tempfile.mkdtemp(prefix=f'{self.TEMP_PREFIX}{pass_name}-')
         logging.debug('Creating pass root folder: %s' % self.root)
 
     def remove_root(self):
@@ -203,8 +209,9 @@ class TestManager:
     def get_line_count(files):
         lines = 0
         for file in files:
-            with open(file) as f:
-                lines += len([line for line in f.readlines() if line and not line.isspace()])
+            if is_readable_file(file):
+                with open(file) as f:
+                    lines += len([line for line in f.readlines() if line and not line.isspace()])
         return lines
 
     def backup_test_cases(self):
@@ -282,7 +289,7 @@ class TestManager:
     def check_sanity(self, verbose=False):
         logging.debug('perform sanity check... ')
 
-        folder = tempfile.mkdtemp(prefix=self.TEMP_PREFIX)
+        folder = tempfile.mkdtemp(prefix=f'{self.TEMP_PREFIX}sanity-')
         test_env = TestEnvironment(None, 0, self.test_script, folder, None, self.test_cases, None)
         logging.debug('sanity check tmpdir = {}'.format(test_env.folder))
 
@@ -475,70 +482,88 @@ class TestManager:
         if not self.skip_key_off:
             logger = KeyLogger()
 
-        for test_case in self.sorted_test_cases:
-            self.current_test_case = test_case
+        try:
+            for test_case in self.sorted_test_cases:
+                self.current_test_case = test_case
 
-            if self.get_file_size([test_case]) == 0:
-                continue
+                if self.get_file_size([test_case]) == 0:
+                    continue
 
-            if not self.no_cache:
-                with open(test_case, mode='r+') as tmp_file:
-                    test_case_before_pass = tmp_file.read()
+                if not self.no_cache:
+                    with open(test_case, mode='rb+') as tmp_file:
+                        test_case_before_pass = tmp_file.read()
 
-                    if (pass_key in self.cache and
-                            test_case_before_pass in self.cache[pass_key]):
-                        tmp_file.seek(0)
-                        tmp_file.truncate(0)
-                        tmp_file.write(self.cache[pass_key][test_case_before_pass])
-                        logging.info('cache hit for {}'.format(test_case))
-                        continue
+                        if (pass_key in self.cache and
+                                test_case_before_pass in self.cache[pass_key]):
+                            tmp_file.seek(0)
+                            tmp_file.truncate(0)
+                            tmp_file.write(self.cache[pass_key][test_case_before_pass])
+                            logging.info('cache hit for {}'.format(test_case))
+                            continue
 
-            # create initial state
-            self.state = self.current_pass.new(self.current_test_case, self.check_sanity)
-            self.skip = False
+                # create initial state
+                self.state = self.current_pass.new(self.current_test_case, self.check_sanity)
+                self.skip = False
 
-            while self.state is not None and not self.skip:
-                # Ignore more key presses after skip has been detected
-                if not self.skip_key_off and not self.skip:
-                    key = logger.pressed_key()
-                    if key == 's':
-                        self.skip = True
-                        self.log_key_event('skipping the rest of this pass')
-                    elif key == 'd':
-                        self.log_key_event('toggle print diff')
-                        self.print_diff = not self.print_diff
+                while self.state is not None and not self.skip:
+                    # Ignore more key presses after skip has been detected
+                    if not self.skip_key_off and not self.skip:
+                        key = logger.pressed_key()
+                        if key == 's':
+                            self.skip = True
+                            self.log_key_event('skipping the rest of this pass')
+                        elif key == 'd':
+                            self.log_key_event('toggle print diff')
+                            self.print_diff = not self.print_diff
 
-                success_env = self.run_parallel_tests()
-                self.kill_pid_queue()
+                    success_env = self.run_parallel_tests()
+                    self.kill_pid_queue()
 
-                if success_env:
-                    self.process_result(success_env)
-                self.release_folders()
-                self.futures.clear()
-                if not success_env:
-                    break
+                    if success_env:
+                        self.process_result(success_env)
+                    self.release_folders()
+                    self.futures.clear()
+                    if not success_env:
+                        break
 
-            # Cache result of this pass
-            if not self.no_cache:
-                with open(test_case, mode='r') as tmp_file:
-                    if pass_key not in self.cache:
-                        self.cache[pass_key] = {}
+                # Cache result of this pass
+                if not self.no_cache:
+                    with open(test_case, mode='rb') as tmp_file:
+                        if pass_key not in self.cache:
+                            self.cache[pass_key] = {}
 
-                    self.cache[pass_key][test_case_before_pass] = tmp_file.read()
+                        self.cache[pass_key][test_case_before_pass] = tmp_file.read()
 
-        self.restore_mode()
-        self.remove_root()
-        self.pass_statistic.stop(self.current_pass)
+            self.restore_mode()
+            self.pass_statistic.stop(self.current_pass)
+            self.remove_root()
+        except KeyboardInterrupt:
+            logging.info('Exiting now ...')
+            self.remove_root()
+            sys.exit(1)
 
     def process_result(self, test_env):
         if self.print_diff:
             diff_str = self.diff_files(self.current_test_case, test_env.test_case_path)
+            if self.use_colordiff:
+                diff_str = subprocess.check_output('colordiff', shell=True, encoding='utf8', input=diff_str)
             logging.info(diff_str)
 
-        shutil.copy(test_env.test_case_path, self.current_test_case)
+        try:
+            shutil.copy(test_env.test_case_path, self.current_test_case)
+        except FileNotFoundError:
+            raise RuntimeError(f"Can't find {self.current_test_case} -- did your interestingness test move it?")
 
         self.state = self.current_pass.advance_on_success(test_env.test_case_path, test_env.state)
         self.pass_statistic.add_success(self.current_pass)
 
         pct = 100 - (self.total_file_size * 100.0 / self.orig_total_file_size)
-        logging.info('({}%, {} bytes, {} lines)'.format(round(pct, 1), self.total_file_size, self.total_line_count))
+        notes = []
+        notes.append(f'{round(pct, 1)}%')
+        notes.append(f'{self.total_file_size} bytes')
+        if self.total_line_count:
+            notes.append(f'{self.total_line_count} lines')
+        if len(self.test_cases) > 1:
+            notes.append(test_env.test_case)
+
+        logging.info('(' + ', '.join(notes) + ')')
